[![CI](https://github.com/DiamondLightSource/dls-ldap-query/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/dls-ldap-query/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/dls-ldap-query/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/dls-ldap-query)
[![PyPI](https://img.shields.io/pypi/v/dls-ldap-query.svg)](https://pypi.org/project/dls-ldap-query)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

# dls_ldap_query

Format lists of users by querying LDAP

Source          | <https://github.com/DiamondLightSource/dls-ldap-query>
:---:           | :---:
PyPI            | `pip install dls-ldap-query`
Docker          | `docker run ghcr.io/diamondlightsource/dls-ldap-query:latest`
Releases        | <https://github.com/DiamondLightSource/dls-ldap-query/releases>

The following command gives details of the command line parameters:

```
dls_ldap_query --help
```
